def create(values = None):
  # "therapyRecommendation": {
  #   "therapyName": []
  #   "therapySensitivity": ...
  # }
  record = {
    "calledBy": None,
    "genomeBuild": None,
    "orientation": None,
    "strand": None,
    "coordinateSystem": None,
    "sequenceType": None,
    "chrom": None,
    "pos": None,
    "ref": None,
    "alt": None,
    "type": None,
    "exact": None,
    "length": None,
    "start": None,
    "end": None,
    "readDepth": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record



def create(values = None):
  # "therapyRecommendation": {
  #   "therapyName": []
  #   "therapySensitivity": ...
  # }
  record = {
    "calledBy": None,
    "genomeBuild": None,
    "coordinateSystem": None,
    "chrom": None,
    "gene": None,
    "refCN": None,
    "cn": None,
    "lowCI": None,
    "lowCIThreshold": None,
    "highCI": None,
    "highCIThreshold": None,
    "log2": None,
    "hotspot": None,
    "call": None,
    "location": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record



def create(values = None):
  # "specimen": {
  #   "accession": ...
  #   "type": {
  #     "code": ...
  #     "display":...
  #     "system": ...
  #   }
  #   "collectedTime": ...
  #   "receivedTime": ...
  #   "collector": ...
  # }
  # "bodySite": {
  #   "code": ...
  #   "display":...
  #   "system": ...
  # }
  record = {
    "sampleId": None,
    "patientId": None,
    "tumorContent": None,
    "disease": None,
    "diseaseOntology": None,
    "detailedDisease": None,
    "detailedDiseaseOntology": None,
    "alternativeDiseaseSystems": None,
    "indication": None,
    "sourceType": None,
    "specimen": None,
    "bodySite": None,
    "age": None
  }
  if values!=None:
    record.update(values)
  return record


def create(values = None):
  record = {
    "ampTier": None,
    "acmgTier": None,
    "alternativeTierSystems": None,
    "calledBy": None,
    "sequenceType": None,
    "coordinateSystem": None,
    "genomeBuild": None,
    "orientation": None,
    "strand": None,
    "chrom": None,
    "pos": None,
    "ref": None,
    "alt": None,
    "filter": None,
    "id": None,
    "qual": None,
    "infoRaw": None,
    "formatRaw": None,
    "sampleRaw": None,
    "genotype": None,
    "readDepth": None,
    "refAlleleDepth": None,
    "altAlleleDepth": None,
    "altAlleleFraction": None,
    "refAlleleDepthFwdStrand": None,
    "refAlleleDepthRevStrand": None,
    "altAlleleDepthFwdStrand": None,
    "altAlleleDepthRevStrand": None,
    "altAlleleFractionFwdStrand": None,
    "altAlleleFractionRevStrand": None,
    "cigar": None,
    "gene": None,
    "transcript": None,
    "protein": None,
    "variantClassification": None,
    "variantType": None,
    "hgvsG": None,
    "hgvsC": None,
    "hgvsP": None,
    "hgvsPShort": None,
    "hotspot": None,
    "zygosity": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record



def create(values = None):
  # "therapyRecommendation": {
  #   "therapyName": []
  #   "therapySensitivity": ...
  # }
  record = {
    "test": None,
    "value": None,
    "threshold": None,
    "component": None,
    "gene": None,
    "expressionType": None,
    "intensity": None,
    "stainPercent": None,
    "result": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record



def create(values = None):
  record = {
    "calledBy": None,
    "name": None,
    "genomeBuild": None,
    "coordinateSystem": None,
    "5pGene": None,
    "5pTranscript": None,
    "5pExon": None,
    "5pChrom": None,
    "5pPos": None,
    "3pGene": None,
    "3pTranscript": None,
    "3pExon": None,
    "3pChrom": None,
    "3pPos": None,
    "support": None,
    "frame": None,
    "read_count": None,
    "normalizedExpression": None,
    "normalization": None,
    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record
